@@ -21,7 +21,11 @@
 */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
+#include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include "gtkhtml-compat.h"
 #include "htmlcursor.h"
@@ -105,7 +109,7 @@ url_requested (GtkHTML *html, const gchar *url, GtkHTMLStream *handle)
 GtkWidget *
 sample_frame (GtkHTML **html)
 {
-	GtkWidget *frame, *scroll_frame, *vbox;
+	GtkWidget *scroll_frame, *vbox;
 
 	*html = GTK_HTML (gtk_html_new ());
 	scroll_frame = gtk_scrolled_window_new (NULL, NULL);
@@ -153,7 +157,7 @@ editor_hig_vbox_full (gchar *text, GtkWidget *control, gboolean vexpand)
 GtkWidget *
 editor_hig_vbox (gchar *text, GtkWidget *control)
 {
-	editor_hig_vbox_full (text, control, FALSE);
+	return editor_hig_vbox_full (text, control, FALSE);
 }
 
 GtkWidget *
