@@ -567,6 +567,12 @@ delete_object_do (HTMLEngine *e, HTMLObject **object, guint *len, HTMLUndoDirect
 	*object  = html_object_op_cut  (HTML_OBJECT (from->data), e, from->next, to->next, left, right, len);
 	position = e->cursor->position;
 	remove_empty_and_merge (e, TRUE, left ? left->next : NULL, right ? right->next : NULL, NULL);
+
+	g_list_free (from);
+	g_list_free (to);
+	g_list_free (left);
+	g_list_free (right);
+
 	e->cursor->position = position;
 	html_engine_spell_check_range (e, e->cursor, e->cursor);
 	html_engine_thaw (e);
@@ -875,6 +881,12 @@ insert_object_do (HTMLEngine *e, HTMLObject *obj, guint *len, gint level, guint
 #endif
 	remove_empty_and_merge (e, TRUE, last, right, orig);
 	remove_empty_and_merge (e, TRUE, left, first, orig);
+
+	g_list_free (first);
+	g_list_free (last);
+	g_list_free (left);
+	g_list_free (right);
+
 #ifdef OP_DEBUG
 	printf ("position after merge %d\n", e->cursor->position);
 #endif
@@ -1723,6 +1735,7 @@ check_for_simple_containers (HTMLObject *child, HTMLObject *parent)
 			switch (child->klass->type) {
 			case HTML_TYPE_CLUEFLOW:
 			case HTML_TYPE_CLUEV:
+			case HTML_TYPE_TABLECELL:
 				break;
 			default:
 				return FALSE;
@@ -1739,7 +1752,7 @@ check_for_simple_delete (HTMLObject *start, HTMLObject *end)
 {
 	HTMLObject *common_parent = get_common_parent (start, end);
 
-	if (common_parent && check_for_simple_containers (start, common_parent) && check_for_simple_containers (end, common_parent))
+	if (common_parent && check_for_simple_containers (start->parent, common_parent) && check_for_simple_containers (end->parent, common_parent))
 		return TRUE;
 
 	return FALSE;
